Function diem_transaction_builder::experimental_stdlib::encode_gc_ballots_script_function[][src]

pub fn encode_gc_ballots_script_function(
    proposal: TypeTag,
    addr: AccountAddress
) -> TransactionPayload
gc_ballots deletes all the expired ballots of the type Proposal under the provided address addr. The signer can be anybody and does not need to have the same address as addr